#!/usr/bin/env python
# -*- coding: utf-8 -*-

from cmd2 import Cmd


class Gs1Cmd(Cmd):
    """!
    Kommandozeilen Interface für Linux.\n
    Neue Befehle können mit do_xxx erstellt werden.\n
    Nach Eingabe eines Befehls wird die entsprechende Funktion im Gs1Controller aufgerufen.\n
    Befehle, die nicht durch eine do_xxx Funktion implementiert sind, werden an den GUI Kommando Parser weitergeleitet.
    """
    def __init__(self, gs1_controller):
        """!
        Init des Command Line Interface.
        Benötigt die Referenz auf den GS1Controller, damit dessen Callbacks aufgerufen werden können.
        """
        self._gs1_controller = gs1_controller
        Cmd.__init__(self, use_ipython=False)

    def do_door(self, arg):
        """!
        Callback für Kommando 'door'. Benötigt ein Argument: 'open', 'close' oder Zahlenwert 0..100. Bewegt die Türe an die entsprechende Position.
        """
        self._gs1_controller.do_door(arg)
        print('door {}'.format(arg))

    def do_load_all_hf_data(self, arg):
        """!
        Callback für Kommando 'do_load_all_hf_data'. Sendet eine Liste aller Heizdateien an die GUI.
        """
        self._gs1_controller.do_load_all_hf_data()

    def do_fc(self, arg):
        """!
        Callback für Kommando 'fc'. Benötigt das Argument on oder off. Schaltet die Zwangskühlung (Lüfter 1) ein oder aus.
        """
        self._gs1_controller.do_fc(arg)

    def do_vacuum(self, arg):
        """!
        Callback für Kommando 'vacuum'. Benötigt das Argument on oder off. Schaltet die Vakuumpumpe für die Brennkammer ein oder aus.
        """
        self._gs1_controller.do_vacuum(arg)

    def do_vent(self, arg):
        """!
        Callback für Kommando 'vent'. Benötigt das Argument on oder off. Schaltet die Entlüftung für die Brennkammer ein oder aus.
        """
        self._gs1_controller.do_vent(arg)

    def do_prot_gas(self, arg):
        """!
        Callback für Kommando 'prot_gas'. Benötigt das Argument on oder off. Schaltet die Argon/Schutzgas-Zuführung für die Brennkammer ein oder aus.
        """
        self._gs1_controller.do_prot_gas(arg)

    def do_res1(self, arg):
        """!
        Callback für Kommando 'res1'. Benötigt das Argument on oder off.
        """
        self._gs1_controller.do_res1(arg)

    def do_res2(self, arg):
        """!
        Callback für Kommando 'res2'. Benötigt das Argument on oder off.
        """
        self._gs1_controller.do_res2(arg)

    def do_res3(self, arg):
        """!
        Callback für Kommando 'res3'. Benötigt das Argument on oder off.
        """
        self._gs1_controller.do_res3(arg)

    def do_res4(self, arg):
        """!
        Callback für Kommando 'res4'. Benötigt das Argument on oder off.
        """
        self._gs1_controller.do_res4(arg)

    def default(self, statement):
        """!
        Leitet Befehle, die nicht durch eine do_xxx Funktion implementiert sind, an den GUI Kommando Parser weiter.
        """
        command_string = statement.full_parsed_statement()
        command_string = command_string.replace(' ', '')
        print command_string + ": " + self._gs1_controller._communication._command_parser.executeCommand(command_string)
